pub struct ConstantPoolIndex(/* private fields */);Expand description
An index into a class file’s constant-pool table.
Index values are preserved exactly as stored in the class file. They are one-based in valid
class files, and some values can refer to unusable reserved slots after Long or Double
constants.
Implementations