pub enum VerificationType<'a> {
Top,
Integer,
Float,
Long,
Double,
Null,
UninitializedThis,
Object {
internal_name: Option<&'a str>,
constant_pool_index: ConstantPoolIndex,
},
Uninitialized {
offset: u16,
},
}Expand description
A verification type stored in a StackMapTable frame.
Variants
Top
An unusable local-variable slot.
Integer
A category-one integral value.
Float
A category-one floating-point value.
Long
A category-two integral value.
Double
A category-two floating-point value.
Null
The JVM null value.
UninitializedThis
The receiver in an instance constructor before initialization completes.
Object
A reference to a class or array type.
Fields

constant_pool_index: ConstantPoolIndexRaw constant-pool index of the class entry.
Uninitialized
An object allocated by new before constructor initialization completes.